HandlerSignature

Enum HandlerSignature 

pub enum HandlerSignature {
    Entry,
    Other {
        obligations: BTreeMap<Type, &'static Location<'static>>,
        guaranteed_outcomes: BTreeSet<Type>,
        conditional_outcomes: BTreeSet<Type>,
        continues: bool,
    },
}
A run-time handler signature. Used only for run-time type inference and checking of handler chains.

See crate::type_check.

Variants



Entry

The signature corresponding to crate::entry.



Other

The handler signature with exact input and output types.

Fields

obligations: BTreeMap<Type, &'static Location<'static>>

The map from types that this handler accepts to locations where they are required in source code.

guaranteed_outcomes: BTreeSet<Type>

The set of types that this handler guarantees to provide when it continues. These types are always available for subsequent handlers in a chain or branch.

conditional_outcomes: BTreeSet<Type>

The set of types that this handler may provide, but only conditionally. These types cannot be relied upon by subsequent handlers.

continues: bool

Whether this handler might continue execution.